package Exception::DB;
$Exception::DB::VERSION = '0.015';
use base qw(Exception);

1;
